
/* Generated data (by glib-mkenums) */

#ifndef __ARIO_ENUM_TYPES_H__
#define __ARIO_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "servers/ario-server.h" */

#define ARIO_TYPE_SERVER_TYPE	(ario_server_type_get_type())
GType ario_server_type_get_type	(void) G_GNUC_CONST;

#define ARIO_TYPE_SERVER_ACTION_TYPE	(ario_server_action_type_get_type())
GType ario_server_action_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "sources/ario-source-manager.h" */

#define ARIO_TYPE_SOURCE_TYPE	(ario_source_type_get_type())
GType ario_source_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "shell/ario-shell.h" */

#define ARIO_TYPE_VISIBILITY	(ario_visibility_get_type())
GType ario_visibility_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* __ARIO_ENUM_TYPES_H__ */

/* Generated data ends here */

